/*********************************************************************/
/*                                                                   */
/* Module Name: AMQODQ0P.L                                           */
/*                                                                   */
/* Description: RUNMQDLQ Parser: LEX                                 */
/*                                                                   */
/* Licensed Materials - Property of IBM                              */
/* 63H9336                                                           */
/* (C) Copyright IBM Corp. 1994,1996.                                */
/*                                                                   */
/*                                                                   */
/*********************************************************************/
/* Following text will be included in the Service Reference Manual.  */
/* Ensure that the content is correct and up-to-date.                */
/* All updates should be made in mixed case.                         */
/*                                                                   */
/* Function:                                                         */
/*                                                                   */
/* This file contains the source for LEX for the parser for          */
/* RUNMQDLQ which generates the file amqodqlp.c (often called        */
/* lexyy.c)                                                          */
/*                                                                   */
/* End of text to be included in SRM                                 */
/*********************************************************************/

%{
/*********************************************************************/
/*                                                                   */
/* Module Name: AMQODQ0P.C                                           */
/*                                                                   */
/* Description: RUNMQDLQ parser: LEX                                 */
/*                                                                   */
/* Statement:     Licensed Materials - Property of IBM               */
/*                                                                   */
/*                5765-115 5621-390 (C) Copyright IBM Corp. 1994     */
/*                                                                   */
/*                U.S. Government Users Restricted Rights - use,     */
/*                duplication or disclosure restricted by GSA ADP    */
/*                Schedule Contract with IBM Corp.                   */
/*                                                                   */
/*********************************************************************/
/*                                                                   */
/* WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING   */
/*   This file was generated by running the LEX program              */
/*                    against the source file                        */
/*                                                                   */
/*   AMQODQ0P.L                                                      */
/*                                                                   */
/*   Updates should be made to the above source file and NOT to      */
/*   this file.                                                      */
/* WARNING WARNING WARNING WARNING WARNING WARNING WARNING WARNING   */
/*                                                                   */
/*********************************************************************/
#undef yywrap
#undef YYLMAX
#define YYLMAX 4096
#include <errno.h>
#include <limits.h>
#include <cmqc.h>
#include <string.h>
#include <amqodqha.h>
#include <amqodqma.h>

/*------------------------------------------------------------------*/
/*  As all versions of Lex do not support yylineno we have to       */
/*  manage a line count ourselves. The line count is referenced in  */
/*  both the lex and the yacc and so we make it global.             */
/*------------------------------------------------------------------*/
int odqLineNo=1;

/*------------------------------------------------------------------*/
/*  I N T E R N A L    F U N C T I O N    P R O T O T Y P E S       */
/*------------------------------------------------------------------*/
static odqResp odqStrDup( /*OUT*/
                            char ** target,
                          /*IN*/
                            const char * source
                        );
static odqResp odqQStrDup( /*OUT*/
                             char ** target,
                           /*IN*/
                             const char * source
                         );
static odqResp odqAtoi( /*OUT*/
                          int * target,
                        /*IN*/
                          const char * source
                      );
static odqResp odqSymbtoi( /*OUT*/
                             int * target,
                           /*IN*/
                             const char * source
                         );
int yywrap (void);

%}

string          ([a-zA-Z0-9_./%]+)
iqname          ({string})
fqname          ({string}|(&{d}{e}{s}{t}{q})|(&{r}{e}{p}{l}{y}{q}))
qmname          ({string})
fqmname         ({string}|(" "*)|(&{d}{e}{s}{t}{q}{m})|(&{r}{e}{p}{l}{y}{q}{m}))
qstring         "'"{string}"'"
qiqname         "'"({iqname}|(" ")*)"'"
qfqname         "'"{fqname}"'"
qqmname         "'"({qmname}|(" ")*)"'"
qfqmname        "'"{fqmname}"'"
wstring         [a-zA-Z0-9_./%*?]+
qwstring        \'([^\']+|(\'\'))*\'
number          [0-9]+
a [aA]
b [bB]
c [cC]
d [dD]
e [eE]
f [fF]
g [gG]
h [hH]
i [iI]
j [jJ]
k [kK]
l [lL]
m [mM]
n [nN]
o [oO]
p [pP]
q [qQ]
r [rR]
s [sS]
t [tT]
u [uU]
v [vV]
w [wW]
x [xX]
y [yY]
z [zZ]

%s QMNAMES QNAMES FWDQMS FWDQS WSTRINGS INTEGERS ACTIONS BOOL WAITS PUTAUTS

%e 8000
%n 3000
%o 15000
%k 2000
%p 36000
%a 18000

%%
%{
/*--------------------------------------------------------------------*/
/* Comment lines are identified by an * in column 1.                  */
/* Comment lines can appear in the middle of some other expression and*/
/* are simply stripped out.                                           */
/* We rely upon the pattern .*\n(\*.*) being longer then the          */
/* pattern controlling trailing +'s and -'s to prevent these          */
/* characters from being meaningful on comment lines.                 */
/* We rely upon the pattern ^\*.*\n being as long as the              */
/* pattern controlling trailing +'s and -'s to prevent these          */
/* characters from being meaningful onthe first line in the file      */
/* We rely on the pattern ^\*.*\n\*.*\n being as long as any other    */
/* pattern so that the special meaning of the ^ is not lost when lines*/
/* are joined/removed etc                                             */ 
/*--------------------------------------------------------------------*/
%}
^\*.*\n                           odqLineNo ++;
^\*.*\n\*.*\n                     odqLineNo += 2;
.*\n(\*.*)                        {
                                    int i ;
                                    char c;
                                    /*--------------------------------*/
                                    /* read forwards for the end      */
                                    /* of line/file.                  */
                                    /*--------------------------------*/
                                    for( c=input();
                                         c!='\n' &&
                                         c!=0 ;
                                         c=input());
                                    /*--------------------------------*/
                                    /* scan the text for the start    */
                                    /* of the comment.                */
                                    /*--------------------------------*/
                                    for( i = 0;
                                         yytext[i] != '\n' ||
                                         yytext[i+1] !='*' ;
                                         i ++);
                                    /*--------------------------------*/
                                    /* Put back the text before       */
                                    /* the start of the comment.      */
                                    /*--------------------------------*/
                                    for( ;
                                         i >= 0;
                                         i -- )
                                         unput(yytext[i]) ;

                                    odqLineNo ++;
                                  }
%{
/*--------------------------------------------------------------------*/
/* The following pattern is intended to strip out null lines.         */
/* The yacc grammar specification is also written to ignore null lines*/
/* because the interaction with the commenting input/unput can cause  */
/* the ^ indicating start of line to fail to match.                   */
/*--------------------------------------------------------------------*/
%}
^[ \t]*\n                         odqLineNo ++;
%{
/*--------------------------------------------------------------------*/
/* The syntax for runmqdlq is based upon the syntax of runmqsc in     */
/* which the '+' and '-' characters cannot be used with a '*' in      */
/* the first character of the new line.                               */
/*--------------------------------------------------------------------*/
%}
%{
/*--------------------------------------------------------------------*/
/* If a line ends with a '+' then it is continued in the first non    */
/* blank character of the following line.                             */
/*--------------------------------------------------------------------*/
%}
.*\+[ \t]*\n[ \t]*                {
                                    int i ;
                                    /*--------------------------------*/
                                    /* Scan forwards for the newline. */
                                    /*--------------------------------*/
                                    for( i = 0;
                                         yytext[i] != '\n';
                                         i ++);
                                    /*--------------------------------*/
                                    /* Scan back to the trailing +    */
                                    /*--------------------------------*/
                                    for( i--;
                                         yytext[i] != '+';
                                         i--);
                                    /*--------------------------------*/
                                    /* Put back the text before the   */
                                    /* trailing +                     */
                                    /*--------------------------------*/
                                    for( i-- ;
                                         i>= 0;
                                         i-- )
                                         unput(yytext[i]) ;
                                    odqLineNo ++;
                                  }
%{
/*--------------------------------------------------------------------*/
/* If a line ends with a '-' then it is continued in the first        */
/* character of the following line.                                   */
/*--------------------------------------------------------------------*/
%}
.*\-[ \t]*\n                      {
                                    int i ;
                                    /*--------------------------------*/
                                    /* Scan forwards for the newline. */
                                    /*--------------------------------*/
                                    for( i = 0;
                                         yytext[i] != '\n';
                                         i++);
                                    /*--------------------------------*/
                                    /* Scan back to the trailing +    */
                                    /*--------------------------------*/
                                    for( i--;
                                         yytext[i] != '-';
                                         i--);
                                    /*--------------------------------*/
                                    /* Put back the text before the   */
                                    /* trailing +                     */
                                    /*--------------------------------*/
                                    for( i-- ;
                                         i >= 0;
                                         i-- )
                                         unput(yytext[i]) ;
                                    odqLineNo ++;
                                  }

<INITIAL>[ \,\t]+                 ;
<INITIAL>\n                       {
                                    odqLineNo ++;
                                    return NEWLINE;
                                  }
\(                                return LBRACKET;

<INITIAL>{f}{o}{r}{m}{a}{t}       {
                                    BEGIN(WSTRINGS);
                                    return FORMAT;
                                  }
<INITIAL>{d}{e}{s}{t}{q}          {
                                    BEGIN(WSTRINGS);
                                    return DESTQ;
                                  }
<INITIAL>{d}{e}{s}{t}{q}{m}       {
                                    BEGIN(WSTRINGS);
                                    return DESTQM;
                                  }
<INITIAL>{r}{e}{p}{l}{y}{q}       {
                                    BEGIN(WSTRINGS);
                                    return REPLYQ;
                                  }
<INITIAL>{r}{e}{p}{l}{y}{q}{m}    {
                                    BEGIN(WSTRINGS);
                                    return REPLYQM;
                                  }
<INITIAL>{a}{p}{p}{l}{i}{d}{a}{t} {
                                    BEGIN(WSTRINGS);
                                    return APPLIDAT;
                                  }
<INITIAL>{a}{p}{p}{l}{t}{y}{p}{e} {
                                    BEGIN(INTEGERS);
                                    return APPLTYPE;
                                  }
<INITIAL>{a}{p}{p}{l}{n}{a}{m}{e} {
                                    BEGIN(WSTRINGS);
                                    return APPLNAME;
                                  }
<INITIAL>{u}{s}{e}{r}{i}{d}       {
                                    BEGIN(WSTRINGS);
                                    return USERID;
                                  }
<INITIAL>{r}{e}{a}{s}{o}{n}       {
                                    BEGIN(INTEGERS);
                                    return REASON;
                                  }
<INITIAL>{m}{s}{g}{t}{y}{p}{e}    {
                                    BEGIN(INTEGERS);
                                    return MSGTYPE;
                                  }
<INITIAL>{f}{e}{e}{d}{b}{a}{c}{k} {
                                    BEGIN(INTEGERS);
                                    return FEEDBACK;
                                  }
<INITIAL>{p}{e}{r}{s}{i}{s}{t}    {
                                    BEGIN(INTEGERS);
                                    return PERSIST;
                                  }
<INITIAL>{a}{c}{t}{i}{o}{n}       {
                                    BEGIN(ACTIONS);
                                    return ACTION;
                                  }
<INITIAL>{h}{e}{a}{d}{e}{r}       {
                                    BEGIN(BOOL);
                                    return HEADER;
                                  }
<INITIAL>{r}{e}{t}{r}{y}          {
                                    BEGIN(INTEGERS);
                                    return RETRY;
                                  }
<INITIAL>{f}{w}{d}{q}             {
                                    BEGIN(FWDQS);
                                    return FWDQ;
                                  }
<INITIAL>{f}{w}{d}{q}{m}          {
                                    BEGIN(FWDQMS);
                                    return FWDQM;
                                  }
<INITIAL>{i}{n}{p}{u}{t}{q}{m}    {
                                    BEGIN(QMNAMES);
                                    return INPUTQM;
                                  }
<INITIAL>{i}{n}{p}{u}{t}{q}       {
                                    BEGIN(QNAMES);
                                    return INPUTQ;
                                  }
<INITIAL>{r}{e}{t}{r}{y}{i}{n}{t} {
                                    BEGIN(INTEGERS);
                                    return RETRYINT;
                                  }
<INITIAL>{w}{a}{i}{t}             {
                                    BEGIN(WAITS);
                                    return WAIT;
                                  }
<INITIAL>{p}{u}{t}{a}{u}{t}       {
                                    BEGIN(PUTAUTS);
                                    return PUTAUT;
                                  }

<ACTIONS>[ \,\t]+                 ;
<ACTIONS>\(                       return LBRACKET;
<ACTIONS>\)                       {
                                    BEGIN(INITIAL) ;
                                    return RBRACKET;
                                  }
<ACTIONS>{d}{i}{s}{c}{a}{r}{d}    {
                                    yylval.o.i = odqDISCARD ;
                                    return INTEGER;
                                  }
<ACTIONS>{i}{g}{n}{o}{r}{e}       {
                                    yylval.o.i = odqIGNORE ;
                                    return INTEGER;
                                  }
<ACTIONS>{r}{e}{t}{r}{y}          {
                                    yylval.o.i = odqRETRY ;
                                    return INTEGER;
                                  }
<ACTIONS>{f}{w}{d}                {
                                    yylval.o.i = odqFORWARD ;
                                    return INTEGER;
                                  }
<ACTIONS>.                        return UNEXPECTED;
<BOOL>\(                          return LBRACKET;
<BOOL>[ \,\t]+                    ;
<BOOL>\)                          {
                                    BEGIN(INITIAL) ;
                                    return RBRACKET;
                                  }
<BOOL>{y}{e}{s}                   {
                                    yylval.o.i = 1 ;
                                    return INTEGER;
                                  }
<BOOL>{n}{o}                      {
                                    yylval.o.i = 0 ;
                                    return INTEGER;
                                  }
<BOOL>.                           return UNEXPECTED;
<WAITS>\(                         return LBRACKET;
<WAITS>[ \,\t]+                   ;
<WAITS>\)                         {
                                    BEGIN(INITIAL) ;
                                    return RBRACKET;
                                  }
<WAITS>{y}{e}{s}                  {
                                    yylval.o.i = -1 ;
                                    return INTEGER;
                                  }
<WAITS>{n}{o}                     {
                                    yylval.o.i = 0 ;
                                    return INTEGER;
                                  }
<WAITS>{number}                   {
                                    odqAtoi( &(yylval.o.i),
                                             (char *)yytext ) ;
                                    return INTEGER ;
                                  }
<WAITS>.                          return UNEXPECTED;
<PUTAUTS>\(                       return LBRACKET;
<PUTAUTS>[ \,\t]+                 ;
<PUTAUTS>\)                       {
                                    BEGIN(INITIAL) ;
                                    return RBRACKET;
                                  }
<PUTAUTS>{d}{e}{f}                {
                                    yylval.o.i = 0 ;
                                    return INTEGER;
                                  }
<PUTAUTS>{c}{t}{x}                {
                                    yylval.o.i = 1 ;
                                    return INTEGER;
                                  }
<PUTAUTS>.                        return UNEXPECTED;
<WSTRINGS>[ \,\t]+                ;
<WSTRINGS>{wstring}               {
                                    odqStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return WSTRING ;
                                  }
<WSTRINGS>{qwstring}              {
                                    odqQStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return WSTRING ;
                                  }
<WSTRINGS>\)                      {
                                    BEGIN(INITIAL);
                                    return RBRACKET;
                                  }
<WSTRINGS>.                       return UNEXPECTED;
<QMNAMES>[ \,\t]+                   ;
<QMNAMES>{qmname}                 {
                                    odqStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<QMNAMES>{qqmname}                {
                                    odqQStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<QMNAMES>\)                       {
                                    BEGIN(INITIAL);
                                    return RBRACKET;
                                  }
<QMNAMES>.                        return UNEXPECTED;
<QNAMES>[ \t]+                    ;
<QNAMES>{iqname}                  {
                                    odqStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<QNAMES>{qiqname}                 {
                                    odqQStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<QNAMES>\)                        {
                                    BEGIN(INITIAL);
                                    return RBRACKET;
                                  }
<QNAMES>.                         return UNEXPECTED;
<FWDQS>[ \,\t]+                     ;
<FWDQS>{fqname}                   {
                                    odqStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<FWDQS>{qfqname}                  {
                                    odqQStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<FWDQS>\)                         {
                                    BEGIN(INITIAL);
                                    return RBRACKET;
                                  }
<FWDQS>.                          return UNEXPECTED;
<FWDQMS>[ \,\t]+                    ;
<FWDQMS>{fqmname}                 {
                                    odqStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<FWDQMS>{qfqmname}                {
                                    odqQStrDup( &(yylval.o.s),
                                               (char *)yytext ) ;
                                    return STRING ;
                                  }
<FWDQMS>\)                        {
                                    BEGIN(INITIAL);
                                    return RBRACKET;
                                  }
<FWDQMS>.                         return UNEXPECTED;
<INTEGERS>[ \,\t]+                  ;
<INTEGERS>\(                      return LBRACKET;
<INTEGERS>{number}                {
                                    odqAtoi( &(yylval.o.i),
                                             (char *)yytext ) ;
                                    return INTEGER ;
                                  }
<INTEGERS>{string}                {
                                    if( odq_Ok == 
                                        odqSymbtoi( &(yylval.o.i),
                                        (char *)yytext ))
                                    {
                                      return INTEGER ; 
                                    }
                                    else
                                    {
                                      return UNEXPECTED ; 
                                    }
                                  }
<INTEGERS>\*                      return DEFAULT;
<INTEGERS>\'\*\'                  return DEFAULT;
<INTEGERS>\)                      {
                                    BEGIN(INITIAL);
                                    return RBRACKET;
                                  }
<INTEGERS>.                       return UNEXPECTED;
.                                 return UNEXPECTED;
%%

#undef  FUNCTION
#define FUNCTION odqtodqStrDup

/*********************************************************************/
/*                                                                   */
/* Function: odqStrDup                                               */
/*                                                                   */
/* Description: process an unquoted string                           */
/*                                                                   */
/* Intended Function: Copy an unquoted string to storage with the    */
/*                    correct lifetime for use in a rule.            */
/*                    Fold the string to upper case.                 */
/*                                                                   */
/* Input Parameters: unquoted string                                 */
/*                                                                   */
/* Output Parameters: folded string                                  */
/*                                                                   */
/* Returns:                                                          */
/*********************************************************************/
static odqResp odqStrDup( /*OUT*/
                            char ** target,
                          /*IN*/
                            const char * source
                         )
{
 odqResp rc=odq_Ok ;
 int l = strlen(source ) ;
 int i ;
/*--------------------------------------------------------------------*/
/* odqStrDup: Handle an unquoted string.                              */
/*            Take a copy of the source string and convert it to      */
/*            upper case.                                             */
/*--------------------------------------------------------------------*/
 odq_fnc_entry( FUNCTION );
 rc = odqGetMem(  l+1,
                 "Parameter",
                 (void **)target );
 if (odq_Error > rc )
 {
   for( i = 0 ;
        i < l ;
        i++ )
   {
     (*target)[i] = toupper(source[i]);
   }
   (*target)[l] = 0 ;
 }
 else
 {
    odqGlobal.odqInputErrorCount ++ ;
 }
 odq_fnc_retcode( FUNCTION, rc ) ;
 return rc ;
}
#undef  FUNCTION
#define FUNCTION odqtodqQStrDup

/*********************************************************************/
/*                                                                   */
/* Function: odqQStrDup                                              */
/*                                                                   */
/* Description: process a quoted string                              */
/*                                                                   */
/* Intended Function: Copy an unquoted string to storage with the    */
/*                    correct lifetime for use in a rule.            */
/*                    Strip off the quotes.                          */
/*                                                                   */
/* Input Parameters: quoted string                                   */
/*                                                                   */
/* Output Parameters: string                                         */
/*                                                                   */
/* Returns:                                                          */
/*********************************************************************/
static odqResp odqQStrDup( /*OUT*/
                             char ** target,
                           /*IN*/
                             const char * source
                         )
{
 odqResp rc=odq_Ok ;
 int l = strlen(source ) - 2 ;
 
/*--------------------------------------------------------------------*/
/* odqQStrDup: Handle a quoted string.                                */
/*             Take a copy of the source string.                      */
/*--------------------------------------------------------------------*/
 odq_fnc_entry( FUNCTION );
 rc = odqGetMem(  l+1,
                 "Parameter",
                 (void **)target );
 if (odq_Error > rc )
 {
   memcpy( *target, &(source[1]), l );
   (*target)[l] = 0 ;
 }
 else
 {
    odqGlobal.odqInputErrorCount ++ ;
 }
 odq_fnc_retcode( FUNCTION, rc ) ;
 return rc ;
}
#undef  FUNCTION
#define FUNCTION odqtodqAtoi

/*********************************************************************/
/*                                                                   */
/* Function: odqAtoi                                                 */
/*                                                                   */
/* Description: Convert a numeric string to an integer.              */
/*                                                                   */
/* Intended Function: Convert an numeric string to an integer.       */
/*                                                                   */
/* Input Parameters: numeric string                                  */
/*                                                                   */
/* Output Parameters: integer                                        */
/*                                                                   */
/* Returns:                                                          */
/*********************************************************************/
static odqResp odqAtoi( /*OUT*/
                          int * target,
                        /*IN*/
                          const char * source
                      )
{
 odqResp rc=odq_Ok ;
/*--------------------------------------------------------------------*/
/* odqAtoi: Handle a numeric string                                   */
/*          Translate a numeric string to an integer.                 */
/*--------------------------------------------------------------------*/
 odq_fnc_entry( FUNCTION );
 *target = atoi( source) ;
 if (((*target == LONG_MAX | *target == LONG_MIN) &&
      ( 0!=errno )) |
    ( *target < 0 |*target > 999999999 ))
 {
   odqFFDC( /*IN*/
               FUNCTION,
               odq_InvalidInteger,
               odqLineNo,
               0,
               source,
               strlen(source),
               "InvalidInteger",
               NULL
             /*OUT*/
           ) ;
    rc = odq_InvalidInteger ;
    odqGlobal.odqInputErrorCount ++ ;
 }
 odq_fnc_retcode( FUNCTION, rc ) ;
 return rc ;
}

#undef  FUNCTION
#define FUNCTION odqtodqSymbtoi

/*********************************************************************/
/*                                                                   */
/* Function: odqSymbtoi                                              */
/*                                                                   */
/* Description: Convert a symbolic value to an integer.              */
/*                                                                   */
/* Intended Function: Convert a symbolic value to an integer.        */
/*                                                                   */
/* Input Parameters: string                                          */
/*                                                                   */
/* Output Parameters: integer                                        */
/*                                                                   */
/* Returns:                                                          */
/*********************************************************************/
static odqResp odqSymbtoi( /*OUT*/
                             int * target,
                           /*IN*/
                             const char * source
                         )
{
 odqResp    rc=odq_Ok ;
 char    *  Upper ;
 int        l = strlen(source ) ;
 int        i ;
 int        fFound=0;

typedef struct _ODQTABLE
   {
   char        szString[40];
   MQLONG      mqrc;
   } ODQTABLE;

#define     ODQTABLE_LENGTH   200

ODQTABLE       aodqTable[ODQTABLE_LENGTH]=
       { {"MQRC_NONE"                     , MQRC_NONE                      },
         {"MQRC_ALIAS_BASE_Q_TYPE_ERROR"  , MQRC_ALIAS_BASE_Q_TYPE_ERROR   },
         {"MQRC_ALIAS_BASE_Q_TYPE_ERROR"  , MQRC_ALIAS_BASE_Q_TYPE_ERROR   },
         {"MQRC_ALIAS_BASE_Q_TYPE_ERROR"  , MQRC_ALIAS_BASE_Q_TYPE_ERROR   },
         {"MQRC_ALREADY_CONNECTED"        , MQRC_ALREADY_CONNECTED         },
         {"MQRC_BACKED_OUT"               , MQRC_BACKED_OUT                },
         {"MQRC_BUFFER_ERROR"             , MQRC_BUFFER_ERROR              },
         {"MQRC_BUFFER_LENGTH_ERROR"      , MQRC_BUFFER_LENGTH_ERROR       },
         {"MQRC_CHAR_ATTR_LENGTH_ERROR"   , MQRC_CHAR_ATTR_LENGTH_ERROR    },
         {"MQRC_CHAR_ATTRS_ERROR"         , MQRC_CHAR_ATTRS_ERROR          },
         {"MQRC_CHAR_ATTRS_TOO_SHORT"     , MQRC_CHAR_ATTRS_TOO_SHORT      },
         {"MQRC_CONNECTION_BROKEN"        , MQRC_CONNECTION_BROKEN         },
         {"MQRC_DATA_LENGTH_ERROR"        , MQRC_DATA_LENGTH_ERROR         },
         {"MQRC_DYNAMIC_Q_NAME_ERROR"     , MQRC_DYNAMIC_Q_NAME_ERROR      },
         {"MQRC_ENVIRONMENT_ERROR"        , MQRC_ENVIRONMENT_ERROR         },
         {"MQRC_EXPIRY_ERROR"             , MQRC_EXPIRY_ERROR              },
         {"MQRC_FEEDBACK_ERROR"           , MQRC_FEEDBACK_ERROR            },
         {"MQRC_GET_INHIBITED"            , MQRC_GET_INHIBITED             },
         {"MQRC_HANDLE_NOT_AVAILABLE"     , MQRC_HANDLE_NOT_AVAILABLE      },
         {"MQRC_HCONN_ERROR"              , MQRC_HCONN_ERROR               },
         {"MQRC_HOBJ_ERROR"               , MQRC_HOBJ_ERROR                },
         {"MQRC_INHIBIT_VALUE_ERROR"      , MQRC_INHIBIT_VALUE_ERROR       },
         {"MQRC_INT_ATTR_COUNT_ERROR"     , MQRC_INT_ATTR_COUNT_ERROR      },
         {"MQRC_INT_ATTR_COUNT_TOO_SMALL" , MQRC_INT_ATTR_COUNT_TOO_SMALL  },
         {"MQRC_INT_ATTRS_ARRAY_ERROR"    , MQRC_INT_ATTRS_ARRAY_ERROR     },
         {"MQRC_SYNCPOINT_LIMIT_REACHED"  , MQRC_SYNCPOINT_LIMIT_REACHED   },
         {"MQRC_MAX_CONNS_LIMIT_REACHED"  , MQRC_MAX_CONNS_LIMIT_REACHED   },
         {"MQRC_MD_ERROR"                 , MQRC_MD_ERROR                  },
         {"MQRC_MISSING_REPLY_TO_Q"       , MQRC_MISSING_REPLY_TO_Q        },
         {"MQRC_MSG_TYPE_ERROR"           , MQRC_MSG_TYPE_ERROR            },
         {"MQRC_MSG_TOO_BIG_FOR_Q"        , MQRC_MSG_TOO_BIG_FOR_Q         },
         {"MQRC_MSG_TOO_BIG_FOR_Q_MGR"    , MQRC_MSG_TOO_BIG_FOR_Q_MGR     },
         {"MQRC_NO_MSG_AVAILABLE"         , MQRC_NO_MSG_AVAILABLE          },
         {"MQRC_NO_MSG_UNDER_CURSOR"      , MQRC_NO_MSG_UNDER_CURSOR       },
         {"MQRC_NOT_AUTHORIZED"           , MQRC_NOT_AUTHORIZED            },
         {"MQRC_NOT_OPEN_FOR_BROWSE"      , MQRC_NOT_OPEN_FOR_BROWSE       },
         {"MQRC_NOT_OPEN_FOR_INPUT"       , MQRC_NOT_OPEN_FOR_INPUT        },
         {"MQRC_NOT_OPEN_FOR_INQUIRE"     , MQRC_NOT_OPEN_FOR_INQUIRE      },
         {"MQRC_NOT_OPEN_FOR_OUTPUT"      , MQRC_NOT_OPEN_FOR_OUTPUT       },
         {"MQRC_NOT_OPEN_FOR_SET"         , MQRC_NOT_OPEN_FOR_SET          },
         {"MQRC_OBJECT_CHANGED"           , MQRC_OBJECT_CHANGED            },
         {"MQRC_OBJECT_IN_USE"            , MQRC_OBJECT_IN_USE             },
         {"MQRC_OBJECT_TYPE_ERROR"        , MQRC_OBJECT_TYPE_ERROR         },
         {"MQRC_OD_ERROR"                 , MQRC_OD_ERROR                  },
         {"MQRC_OPTION_NOT_VALID_FOR_TYPE", MQRC_OPTION_NOT_VALID_FOR_TYPE },
         {"MQRC_OPTIONS_ERROR"            , MQRC_OPTIONS_ERROR             },
         {"MQRC_PERSISTENCE_ERROR"        , MQRC_PERSISTENCE_ERROR         },
         {"MQRC_PERSISTENT_NOT_ALLOWED"   , MQRC_PERSISTENT_NOT_ALLOWED    },
         {"MQRC_PRIORITY_EXCEEDS_MAXIMUM" , MQRC_PRIORITY_EXCEEDS_MAXIMUM  },
         {"MQRC_PRIORITY_ERROR"           , MQRC_PRIORITY_ERROR            },
         {"MQRC_PUT_INHIBITED"            , MQRC_PUT_INHIBITED             },
         {"MQRC_Q_DELETED"                , MQRC_Q_DELETED                 },
         {"MQRC_Q_FULL"                   , MQRC_Q_FULL                    },
         {"MQRC_Q_NOT_EMPTY"              , MQRC_Q_NOT_EMPTY               },
         {"MQRC_Q_SPACE_NOT_AVAILABLE"    , MQRC_Q_SPACE_NOT_AVAILABLE     },
         {"MQRC_Q_TYPE_ERROR"             , MQRC_Q_TYPE_ERROR              },
         {"MQRC_Q_MGR_NAME_ERROR"         , MQRC_Q_MGR_NAME_ERROR          },
         {"MQRC_Q_MGR_NOT_AVAILABLE"      , MQRC_Q_MGR_NOT_AVAILABLE       },
         {"MQRC_REPORT_OPTIONS_ERROR"     , MQRC_REPORT_OPTIONS_ERROR      },
         {"MQRC_SECOND_MARK_NOT_ALLOWED"  , MQRC_SECOND_MARK_NOT_ALLOWED   },
         {"MQRC_SECURITY_ERROR"           , MQRC_SECURITY_ERROR            },
         {"MQRC_SELECTOR_COUNT_ERROR"     , MQRC_SELECTOR_COUNT_ERROR      },
         {"MQRC_SELECTOR_LIMIT_EXCEEDED"  , MQRC_SELECTOR_LIMIT_EXCEEDED   },
         {"MQRC_SELECTOR_ERROR"           , MQRC_SELECTOR_ERROR            },
         {"MQRC_SELECTOR_NOT_FOR_TYPE"    , MQRC_SELECTOR_NOT_FOR_TYPE     },
         {"MQRC_SIGNAL_OUTSTANDING"       , MQRC_SIGNAL_OUTSTANDING        },
         {"MQRC_SIGNAL_REQUEST_ACCEPTED"  , MQRC_SIGNAL_REQUEST_ACCEPTED   },
         {"MQRC_STORAGE_NOT_AVAILABLE"    , MQRC_STORAGE_NOT_AVAILABLE     },
         {"MQRC_SYNCPOINT_NOT_AVAILABLE"  , MQRC_SYNCPOINT_NOT_AVAILABLE   },
         {"MQRC_TRIGGER_CONTROL_ERROR"    , MQRC_TRIGGER_CONTROL_ERROR     },
         {"MQRC_TRIGGER_DEPTH_ERROR"      , MQRC_TRIGGER_DEPTH_ERROR       },
         {"MQRC_TRIGGER_MSG_PRIORITY_ERR" , MQRC_TRIGGER_MSG_PRIORITY_ERR  },
         {"MQRC_TRIGGER_TYPE_ERROR"       , MQRC_TRIGGER_TYPE_ERROR        },
         {"MQRC_TRUNCATED_MSG_ACCEPTED"   , MQRC_TRUNCATED_MSG_ACCEPTED    },
         {"MQRC_TRUNCATED_MSG_FAILED"     , MQRC_TRUNCATED_MSG_FAILED      },
         {"MQRC_UNKNOWN_ALIAS_BASE_Q"     , MQRC_UNKNOWN_ALIAS_BASE_Q      },
         {"MQRC_UNKNOWN_OBJECT_NAME"      , MQRC_UNKNOWN_OBJECT_NAME       },
         {"MQRC_UNKNOWN_OBJECT_Q_MGR"     , MQRC_UNKNOWN_OBJECT_Q_MGR      },
         {"MQRC_UNKNOWN_REMOTE_Q_MGR"     , MQRC_UNKNOWN_REMOTE_Q_MGR      },
         {"MQRC_WAIT_INTERVAL_ERROR"      , MQRC_WAIT_INTERVAL_ERROR       },
         {"MQRC_XMIT_Q_TYPE_ERROR"        , MQRC_XMIT_Q_TYPE_ERROR         },
         {"MQRC_XMIT_Q_USAGE_ERROR"       , MQRC_XMIT_Q_USAGE_ERROR        },
         {"MQRC_NOT_OPEN_FOR_PASS_ALL"    , MQRC_NOT_OPEN_FOR_PASS_ALL     },
         {"MQRC_NOT_OPEN_FOR_PASS_IDENT"  , MQRC_NOT_OPEN_FOR_PASS_IDENT   },
         {"MQRC_NOT_OPEN_FOR_SET_ALL"     , MQRC_NOT_OPEN_FOR_SET_ALL      },
         {"MQRC_NOT_OPEN_FOR_SET_IDENT"   , MQRC_NOT_OPEN_FOR_SET_IDENT    },
         {"MQRC_CONTEXT_HANDLE_ERROR"     , MQRC_CONTEXT_HANDLE_ERROR      },
         {"MQRC_CONTEXT_NOT_AVAILABLE"    , MQRC_CONTEXT_NOT_AVAILABLE     },
         {"MQRC_SIGNAL1_ERROR"            , MQRC_SIGNAL1_ERROR             },
         {"MQRC_OBJECT_ALREADY_EXISTS"    , MQRC_OBJECT_ALREADY_EXISTS     },
         {"MQRC_OBJECT_DAMAGED"           , MQRC_OBJECT_DAMAGED            },
         {"MQRC_RESOURCE_PROBLEM"         , MQRC_RESOURCE_PROBLEM          },
         {"MQRC_ANOTHER_Q_MGR_CONNECTED"  , MQRC_ANOTHER_Q_MGR_CONNECTED   },
         {"MQRC_UNKNOWN_REPORT_OPTION"    , MQRC_UNKNOWN_REPORT_OPTION     },
         {"MQRC_SUPPRESSED_BY_EXIT"       , MQRC_SUPPRESSED_BY_EXIT        },
         {"MQRC_FORMAT_ERROR"             , MQRC_FORMAT_ERROR              },
         {"MQRC_SOURCE_CCSID_ERROR"       , MQRC_SOURCE_CCSID_ERROR        },
         {"MQRC_SOURCE_INTEGER_ENC_ERROR" , MQRC_SOURCE_INTEGER_ENC_ERROR  },
         {"MQRC_SOURCE_DECIMAL_ENC_ERROR" , MQRC_SOURCE_DECIMAL_ENC_ERROR  },
         {"MQRC_SOURCE_FLOAT_ENC_ERROR"   , MQRC_SOURCE_FLOAT_ENC_ERROR    },
         {"MQRC_TARGET_CCSID_ERROR"       , MQRC_TARGET_CCSID_ERROR        },
         {"MQRC_TARGET_INTEGER_ENC_ERROR" , MQRC_TARGET_INTEGER_ENC_ERROR  },
         {"MQRC_TARGET_DECIMAL_ENC_ERROR" , MQRC_TARGET_DECIMAL_ENC_ERROR  },
         {"MQRC_TARGET_FLOAT_ENC_ERROR"   , MQRC_TARGET_FLOAT_ENC_ERROR    },
         {"MQRC_NOT_CONVERTED"            , MQRC_NOT_CONVERTED             },
         {"MQRC_CONVERTED_MSG_TOO_BIG"    , MQRC_CONVERTED_MSG_TOO_BIG     },
         {"MQRC_ADAPTER_STORAGE_SHORTAGE" , MQRC_ADAPTER_STORAGE_SHORTAGE  },
         {"MQRC_ADAPTER_CONN_LOAD_ERROR"  , MQRC_ADAPTER_CONN_LOAD_ERROR   },
         {"MQRC_ADAPTER_SERV_LOAD_ERROR"  , MQRC_ADAPTER_SERV_LOAD_ERROR   },
         {"MQRC_ADAPTER_DEFS_ERROR"       , MQRC_ADAPTER_DEFS_ERROR        },
         {"MQRC_ADAPTER_DEFS_LOAD_ERROR"  , MQRC_ADAPTER_DEFS_LOAD_ERROR   },
         {"MQRC_ADAPTER_DISC_LOAD_ERROR"  , MQRC_ADAPTER_DISC_LOAD_ERROR   },
         {"MQRC_CICS_WAIT_FAILED"         , MQRC_CICS_WAIT_FAILED          },
         {"MQRC_SOURCE_LENGTH_ERROR"      , MQRC_SOURCE_LENGTH_ERROR       },
         {"MQRC_TARGET_LENGTH_ERROR"      , MQRC_TARGET_LENGTH_ERROR       },
         {"MQRC_SOURCE_BUFFER_ERROR"      , MQRC_SOURCE_BUFFER_ERROR       },
         {"MQRC_TARGET_BUFFER_ERROR"      , MQRC_TARGET_BUFFER_ERROR       },
         {"MQRC_DBCS_ERROR"               , MQRC_DBCS_ERROR                },
         {"MQRC_TRUNCATED"                , MQRC_TRUNCATED                 },
         {"MQRC_ASID_MISMATCH"            , MQRC_ASID_MISMATCH             },
         {"MQRC_CONN_ID_IN_USE"           , MQRC_CONN_ID_IN_USE            },
         {"MQRC_Q_MGR_QUIESCING"          , MQRC_Q_MGR_QUIESCING           },
         {"MQRC_Q_MGR_STOPPING"           , MQRC_Q_MGR_STOPPING            },
         {"MQRC_DUPLICATE_RECOV_COORD"    , MQRC_DUPLICATE_RECOV_COORD     },
         {"MQRC_PMO_ERROR"                , MQRC_PMO_ERROR                 },
         {"MQRC_API_EXIT_NOT_FOUND"       , MQRC_API_EXIT_NOT_FOUND        },
         {"MQRC_API_EXIT_LOAD_ERROR"      , MQRC_API_EXIT_LOAD_ERROR       },
         {"MQRC_REMOTE_Q_NAME_ERROR"      , MQRC_REMOTE_Q_NAME_ERROR       },
         {"MQRC_GMO_ERROR"                , MQRC_GMO_ERROR                 },
         {"MQRC_PAGESET_FULL"             , MQRC_PAGESET_FULL              },
         {"MQRC_PAGESET_ERROR"            , MQRC_PAGESET_ERROR             },
         {"MQRC_NAME_NOT_VALID_FOR_TYPE"  , MQRC_NAME_NOT_VALID_FOR_TYPE   },
         {"MQRC_UNEXPECTED_ERROR"         , MQRC_UNEXPECTED_ERROR          },
         {"MQRC_UNKNOWN_XMIT_Q"           , MQRC_UNKNOWN_XMIT_Q            },
         {"MQRC_UNKNOWN_DEF_XMIT_Q"       , MQRC_UNKNOWN_DEF_XMIT_Q        },
         {"MQRC_DEF_XMIT_Q_TYPE_ERROR"    , MQRC_DEF_XMIT_Q_TYPE_ERROR     },
         {"MQRC_DEF_XMIT_Q_USAGE_ERROR"   , MQRC_DEF_XMIT_Q_USAGE_ERROR    },
         {"MQRC_NAME_IN_USE"              , MQRC_NAME_IN_USE               },
         {"MQRC_CONNECTION_QUIESCING"     , MQRC_CONNECTION_QUIESCING      },
         {"MQRC_CONNECTION_STOPPING"      , MQRC_CONNECTION_STOPPING       },
         {"MQRC_ADAPTER_NOT_AVAILABLE"    , MQRC_ADAPTER_NOT_AVAILABLE     },
         {"MQRC_MSG_ID_ERROR"             , MQRC_MSG_ID_ERROR              },
         {"MQRC_CORREL_ID_ERROR"          , MQRC_CORREL_ID_ERROR           },
         {"MQRC_FILE_SYSTEM_ERROR"        , MQRC_FILE_SYSTEM_ERROR         },
         {"MQRC_NO_MSG_LOCKED"            , MQRC_NO_MSG_LOCKED             },
         {"MQRC_FILE_NOT_AUDITED"         , MQRC_FILE_NOT_AUDITED          },
         {"MQRC_CONNECTION_NOT_AUTHORIZED", MQRC_CONNECTION_NOT_AUTHORIZED },
         {"MQRC_MSG_TOO_BIG_FOR_CHANNEL"  , MQRC_MSG_TOO_BIG_FOR_CHANNEL   },
         {"MQRC_CALL_IN_PROGRESS"         , MQRC_CALL_IN_PROGRESS          },
         {"MQRC_Q_MGR_ACTIVE"             , MQRC_Q_MGR_ACTIVE              },
         {"MQRC_Q_MGR_NOT_ACTIVE"         , MQRC_Q_MGR_NOT_ACTIVE          },
         {"MQRC_Q_DEPTH_HIGH"             , MQRC_Q_DEPTH_HIGH              },
         {"MQRC_Q_DEPTH_LOW"              , MQRC_Q_DEPTH_LOW               },
         {"MQRC_Q_SERVICE_INTERVAL_HIGH"  , MQRC_Q_SERVICE_INTERVAL_HIGH   },
         {"MQRC_Q_SERVICE_INTERVAL_OK"    , MQRC_Q_SERVICE_INTERVAL_OK     },
         {"MQRC_HCONFIG_ERROR"            , MQRC_HCONFIG_ERROR             },
         {"MQRC_FUNCTION_ERROR"           , MQRC_FUNCTION_ERROR            },
         {"MQRC_CHANNEL_STARTED"          , MQRC_CHANNEL_STARTED           },
         {"MQRC_CHANNEL_STOPPED"          , MQRC_CHANNEL_STOPPED           },
         {"MQRC_CHANNEL_CONV_ERROR"       , MQRC_CHANNEL_CONV_ERROR        },
         {"MQRC_SERVICE_NOT_AVAILABLE"    , MQRC_SERVICE_NOT_AVAILABLE     },
         {"MQRC_INITIALIZATION_FAILED"    , MQRC_INITIALIZATION_FAILED     },
         {"MQRC_TERMINATION_FAILED"       , MQRC_TERMINATION_FAILED        },
         {"MQRC_UNKNOWN_Q_NAME"           , MQRC_UNKNOWN_Q_NAME            },
         {"MQRC_SERVICE_ERROR"            , MQRC_SERVICE_ERROR             },
         {"MQRC_Q_ALREADY_EXISTS"         , MQRC_Q_ALREADY_EXISTS          },
         {"MQRC_USER_ID_NOT_AVAILABLE"    , MQRC_USER_ID_NOT_AVAILABLE     },
         {"MQRC_UNKNOWN_ENTITY"           , MQRC_UNKNOWN_ENTITY            },
         {"MQRC_UNKNOWN_AUTH_ENTITY"      , MQRC_UNKNOWN_AUTH_ENTITY       },
         {"MQRC_UNKNOWN_REF_OBJECT"       , MQRC_UNKNOWN_REF_OBJECT        },
         {"MQRC_CHANNEL_ACTIVATED"        , MQRC_CHANNEL_ACTIVATED         },
         {"MQRC_CHANNEL_NOT_ACTIVATED"    , MQRC_CHANNEL_NOT_ACTIVATED     },
         {"MQMT_SYSTEM_FIRST"             , MQMT_SYSTEM_FIRST              },
         {"MQMT_REQUEST"                  , MQMT_REQUEST                   },
         {"MQMT_REPLY"                    , MQMT_REPLY                     },
         {"MQMT_DATAGRAM"                 , MQMT_DATAGRAM                  },
         {"MQMT_REPORT"                   , MQMT_REPORT                    },
         {"MQMT_SYSTEM_LAST"              , MQMT_SYSTEM_LAST               },
         {"MQMT_APPL_FIRST"               , MQMT_APPL_FIRST                },
         {"MQMT_APPL_LAST"                , MQMT_APPL_LAST                 },
         {"MQFB_NONE"                     , MQFB_NONE                      },
         {"MQFB_SYSTEM_FIRST"             , MQFB_SYSTEM_FIRST              },
         {"MQFB_EXPIRATION"               , MQFB_EXPIRATION                },
         {"MQFB_COA"                      , MQFB_COA                       },
         {"MQFB_COD"                      , MQFB_COD                       },
         {"MQFB_QUIT"                     , MQFB_QUIT                      },
         {"MQFB_CHANNEL_COMPLETED"        , MQFB_CHANNEL_COMPLETED         },
         {"MQFB_CHANNEL_FAIL_RETRY"       , MQFB_CHANNEL_FAIL_RETRY        },
         {"MQFB_CHANNEL_FAIL"             , MQFB_CHANNEL_FAIL              },
         {"MQFB_APPL_CANNOT_BE_STARTED"   , MQFB_APPL_CANNOT_BE_STARTED    },
         {"MQFB_TM_ERROR"                 , MQFB_TM_ERROR                  },
         {"MQFB_APPL_TYPE_ERROR"          , MQFB_APPL_TYPE_ERROR           },
         {"MQFB_STOPPED_BY_MSG_EXIT"      , MQFB_STOPPED_BY_MSG_EXIT       },
         {"MQFB_XMIT_Q_MSG_ERROR"         , MQFB_XMIT_Q_MSG_ERROR          },
         {"MQFB_SYSTEM_LAST"              , MQFB_SYSTEM_LAST               },
         {"MQFB_APPL_FIRST"               , MQFB_APPL_FIRST                },
         {"MQFB_APPL_LAST"                , MQFB_APPL_LAST                 },
         {"MQPER_PERSISTENT"              , MQPER_PERSISTENT               },
         {"MQPER_NOT_PERSISTENT"          , MQPER_NOT_PERSISTENT           },
         {"MQPER_PERSISTENCE_AS_Q_DEF"    , MQPER_PERSISTENCE_AS_Q_DEF     }
       };
 
 odq_fnc_entry( FUNCTION );
 rc = odqGetMem(  l+1,
                 "Symbol",
                 (void **)&Upper );
 if (odq_Error > rc )
 {
   for( i = 0 ;
        i < l ;
        i++ )
   {
     (Upper)[i] = toupper(source[i]);
   }
   (Upper)[l] = 0 ;


   for (i=0;i<ODQTABLE_LENGTH;i++)
   {
      if (strcmp(Upper,aodqTable[i].szString) == 0 )
      {
         *target = aodqTable[i].mqrc;
         fFound = 1;
      } /* endif */
   } /* endfor */
   if (!fFound)
   {
      rc = odq_InvalidInteger ;
   } /* endif */

 }
 else
 {
    rc = odq_InvalidInteger ;
 }
 odqFreeMem( "Symbol", Upper );

 odq_fnc_retcode( FUNCTION, rc ) ;
 return rc ;
}

/*********************************************************************/
/*                                                                   */
/* Function: yywrap                                                  */
/*                                                                   */
/* Description: Process EOF                                          */
/*                                                                   */
/* Intended Function: CoRmplete parsing the input at the first EOF.  */
/*                                                                   */
/* Input Parameters: none                                            */
/*                                                                   */
/* Output Parameters: none                                           */
/*                                                                   */
/* Returns:                                                          */
/*********************************************************************/
int yywrap(void) { return 1; }

/*********************************************************************/
/*                                                                   */
/* Function: yyerror                                                 */
/*                                                                   */
/* Description: Report lex/yacc detected errors                      */
/*                                                                   */
/* Intended Function: Identify errors in the rule table.             */
/*                                                                   */
/* Input Parameters: descriptive string                              */
/*                                                                   */
/* Output Parameters: none                                           */
/*                                                                   */
/* Returns:                                                          */
/*********************************************************************/
/*--------------------------------------------------------------------*/
/* yyerror:                                                           */
/*                                                                    */
/*                                                                    */
/*--------------------------------------------------------------------*/
void yyerror( char * s)
{
 char c;

/*--------------------------------------------------------------------*/
/* We have to remove comments and join up lines before checking the   */
/* grammar to handle with templates of the form:                      */
/*

format(myformat) msgtype(1234+
*comments can appear in the middle of parameters
 5678) action(ignore)

*/
/* This makes it very difficult to match up errors with the input     */
/* source, because after we've joined up the line then we're          */
/* dealing with a line which does not appear verbatim in the          */
/* input file.                                                        */
/*                                                                    */
/*--------------------------------------------------------------------*/

 odqGlobal.odqInputErrorCount ++ ;
 fprintf(stderr, "\n%s on line %d\n", s, odqLineNo ) ;
 /*--------------------------------*/
 /* read forwards for the end      */
 /* of line/file.                  */
 /*--------------------------------*/
 fprintf(stderr,"%s%s", "...", yytext);
 for( c=input();
      c!='\n' &&
      c!=0 ;
      c=input())
 {
   fputc( c, stderr ) ;
 }
 fputc( c, stderr ) ;
 fflush(stderr);
 unput('\n');
 BEGIN(INITIAL);
}

